@@ -62,7 +62,7 @@ class CombilogHandler(Handler):
 
     def _generate_on_error(self):
         def on_error(ws: WebSocketApp, error: str):
-            print("Combilog aggreagtor connection errored: " + error)
+            print("Combilog aggreagtor connection errored: ".format(error))
             threading.Timer(5, self._retry_connect).start()
 
         return on_error
